SegmentedMessage class

============================================================================= CLASS: SegmentedMessage PURPOSE: Manages the segmentation and encoding of SMS messages based on specified encoding formats. It supports encoding into GSM-7 and UCS-2 character sets and can handle different line break styles.

Constructors

SegmentedMessage(String message, [SmsEncodingMode encodingMode = SmsEncodingMode.auto, bool smartEncoding = false])
Constructor for the SegmentedMessage class.

Properties

encodedChars List<EncodedChar>
Encoded characters after processing the message content
getter/setter pair
encoding SmsEncoding
Actual encoding used for the SMS message after processing
getter/setter pair
encodingMode SmsEncodingMode
Encoding mode format for the SMS message, defaults to auto-detection
getter/setter pair
graphemes List<String>
List of graphemes in the message
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lineBreakStyle LineBreakStyle?
Style of line breaks in the message
getter/setter pair
maxCharsPerSegment int
The maximum number of characters that can fit in a single SMS segment given the current encoding.
no setter
messageSize int
Calculates the message size in bits, excluding any user data headers.
no setter
numberOfCharacters int
Total number of characters in the message
getter/setter pair
numberOfUnicodeScalars int
Total number of Unicode scalars in the message
getter/setter pair
remainingCharsInSegment int
The number of characters that can still be added to the current (last) segment before a new segment would be created.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<Segment>
List of segments created for the SMS message
getter/setter pair
segmentsCount int
Gets the number of segments in the message.
no setter
totalSize int
Calculates the total size in bits of the entire message.
no setter
warnings List<String>
List of warnings detected during message processing
getter/setter pair

Methods

getNonGsmCharacters() List<String?>
Retrieves a list of characters that are not GSM-7 encoded.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited